ItemEntityState

Struct ItemEntityState 

struct ItemEntityState {
    age: i32,
    pickup_delay: i32,
    health: i32,
    thrower: Option<Uuid>,
    owner: Option<Uuid>,
}
Mutable item-specific state that changes during item ticks, pickup, damage, merging, and save/load.

Fields

age: i32

Age in ticks. Despawns at LIFETIME (6000). Special value -32768 = infinite.

pickup_delay: i32

Ticks until pickupable. 0 = can pickup, 32767 = never.

health: i32

Health (damage resistance). Item is destroyed when this reaches 0.

thrower: Option<Uuid>

UUID of the entity that threw/dropped this item.

owner: Option<Uuid>

UUID of the only entity that can pick up this item. If None, any player can pick it up. Vanilla calls this target.

Implementations

Source

impl ItemEntityState

const fn new() -> Self